@@ -88,6 +88,7 @@
 
 #else  /* !NATIVE_WIN32 */
 
+#ifndef __EMX__
 /* Unix */
 
 #define G_DIR_SEPARATOR '/'
@@ -95,6 +96,16 @@
 #define G_SEARCHPATH_SEPARATOR ':'
 #define G_SEARCHPATH_SEPARATOR_S ":"
 
+#else
+/* EMX/OS2 */
+
+#define G_DIR_SEPARATOR '/'
+#define G_DIR_SEPARATOR_S "/"
+#define G_SEARCHPATH_SEPARATOR ';'
+#define G_SEARCHPATH_SEPARATOR_S ";"
+
+#endif
+
 #endif /* !NATIVE_WIN32 */
 
 #ifdef __cplusplus
@@ -1280,16 +1291,32 @@ GLogLevelFlags	g_log_set_always_fatal	(GLogLevelFlags	 fatal_mask);
 #ifndef	G_LOG_DOMAIN
 #define	G_LOG_DOMAIN	((gchar*) 0)
 #endif	/* G_LOG_DOMAIN */
-#ifdef	__GNUC__
-#define	g_error(format, args...)	g_log (G_LOG_DOMAIN, \
-					       G_LOG_LEVEL_ERROR, \
-					       format, ##args)
-#define	g_message(format, args...)	g_log (G_LOG_DOMAIN, \
-					       G_LOG_LEVEL_MESSAGE, \
-					       format, ##args)
-#define	g_warning(format, args...)	g_log (G_LOG_DOMAIN, \
-					       G_LOG_LEVEL_WARNING, \
-					       format, ##args)
+#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+#define	g_error(...)	g_log (G_LOG_DOMAIN,         \
+			       G_LOG_LEVEL_ERROR,    \
+			       __VA_ARGS__)
+#define	g_message(...)	g_log (G_LOG_DOMAIN,         \
+			       G_LOG_LEVEL_MESSAGE,  \
+			       __VA_ARGS__)
+#define	g_critical(...)	g_log (G_LOG_DOMAIN,         \
+			       G_LOG_LEVEL_CRITICAL, \
+			       __VA_ARGS__)
+#define	g_warning(...)	g_log (G_LOG_DOMAIN,         \
+			       G_LOG_LEVEL_WARNING,  \
+			       __VA_ARGS__)
+#elif defined (__GNUC__)
+#define	g_error(format...)	g_log (G_LOG_DOMAIN,         \
+				       G_LOG_LEVEL_ERROR,    \
+				       format)
+#define	g_message(format...)	g_log (G_LOG_DOMAIN,         \
+				       G_LOG_LEVEL_MESSAGE,  \
+				       format)
+#define	g_critical(format...)	g_log (G_LOG_DOMAIN,         \
+				       G_LOG_LEVEL_CRITICAL, \
+				       format)
+#define	g_warning(format...)	g_log (G_LOG_DOMAIN,         \
+				       G_LOG_LEVEL_WARNING,  \
+				       format)
 #else	/* !__GNUC__ */
 static void
 g_error (const gchar *format,
@@ -1527,6 +1554,9 @@ gchar*  g_path_skip_root	(gchar       *file_name);
 /* strings are newly allocated with g_malloc() */
 gchar*	g_dirname		(const gchar *file_name);
 gchar*	g_get_current_dir	(void);
+
+/* return the environment string for the variable. The returned memory
+ * must not be freed. */
 gchar*  g_getenv		(const gchar *variable);
 
 
@@ -1647,9 +1677,9 @@ void	 g_string_sprintfa  (GString	 *string,
  * order by moving the last element to the position of the removed 
  */
 
-#define g_array_append_val(a,v)	  g_array_append_vals (a, &v, 1)
-#define g_array_prepend_val(a,v)  g_array_prepend_vals (a, &v, 1)
-#define g_array_insert_val(a,i,v) g_array_insert_vals (a, i, &v, 1)
+#define g_array_append_val(a,v)	  g_array_append_vals (a, &(v), 1)
+#define g_array_prepend_val(a,v)  g_array_prepend_vals (a, &(v), 1)
+#define g_array_insert_val(a,i,v) g_array_insert_vals (a, i, &(v), 1)
 #define g_array_index(a,t,i)      (((t*) (a)->data) [(i)])
 
 GArray* g_array_new	          (gboolean	    zero_terminated,
@@ -1747,6 +1777,7 @@ gchar*	  g_quark_to_string		(GQuark		 quark);
 
 
 /* Keyed Data List
+ * NOTE: these functions are scheduled for a rename in GLib 1.3
  */
 void	  g_datalist_init		 (GData		 **datalist);
 void	  g_datalist_clear		 (GData		 **datalist);
@@ -1778,6 +1809,7 @@ void	  g_datalist_foreach		 (GData		 **datalist,
 
 
 /* Location Associated Keyed Data
+ * NOTE: these functions are scheduled for a rename in GLib 1.3
  */
 void	  g_dataset_destroy		(gconstpointer	  dataset_location);
 gpointer  g_dataset_id_get_data		(gconstpointer	  dataset_location,
@@ -2408,7 +2440,7 @@ struct _GSourceFuncs
 			GTimeVal *current_time,
 			gpointer  user_data);
   gboolean (*dispatch) (gpointer  source_data, 
-			GTimeVal *current_time,
+			GTimeVal *dispatch_time,
 			gpointer  user_data);
   GDestroyNotify destroy;
 };
@@ -2436,7 +2468,7 @@ gboolean g_source_remove_by_source_data      (gpointer       source_data);
 gboolean g_source_remove_by_funcs_user_data  (GSourceFuncs  *funcs,
 					      gpointer       user_data);
 
-void g_get_current_time		    (GTimeVal	   *result);
+void g_get_current_time		        (GTimeVal	*result);
 
 /* Running the main loop */
 GMainLoop*	g_main_new		(gboolean	 is_running);
@@ -2677,7 +2709,7 @@ GUTILS_C_VAR gboolean		g_threads_got_initialized;
  * only be called once, and must not be called directly or indirectly
  * from another glib-function, e.g. as a callback.
  */
-void	g_thread_init	(GThreadFunctions	*vtable);
+void   g_thread_init   (GThreadFunctions       *vtable);
 
 /* internal function for fallback static mutex implementation */
 GMutex*	g_static_mutex_get_mutex_impl	(GMutex	**mutex);
